import _globals
import pytest
import framework.common.decorators as decorator
from framework.selenium.selenium_test import SeleniumTest
from selenium.common.exceptions import NoSuchElementException

pytestmark = [pytest.mark.suite("bvt"), pytest.mark.priority("p1"),
              pytest.mark.project("safeview")]

@decorator.on_platforms(_globals.agent_by_name)
@pytest.mark.component("rendering")
class TestAttributeFiltering(SeleniumTest):
   def test_filter_meta_csp(self):
      """Test removing <meta http-equiv='Content-Security-Policy'>."""
      self.driver.get_test_page('21-dom-operation/dom-meta-http-equiv-csp.html')
      self.assertRaises(NoSuchElementException, self.driver.find_element_by_tag_name, 'meta')

   def test_filter_meta_csp_mutation(self):
      """
      Test removing <meta http-equiv='Content-Security-Policy'> if The
      'http-equiv' attribute of the meta tag is dynamically added.
      to meta tag.
      """
      self.driver.get_test_page('21-dom-operation/dom-add-http-equiv-to-meta.html')
      # Add CSP for http-equiv attribute
      self.driver.wait_for_id('add_csp').click()
      self.driver.wait_for_id('check').click()
      self.driver.wait_for_text_in_page_source("This should be displayed")